=======================
The weylchamber package
=======================

.. image:: https://img.shields.io/badge/github-qucontrol/weylchamber-blue.svg
   :alt: Source code on Github
   :target: https://github.com/qucontrol/weylchamber
.. image:: https://img.shields.io/pypi/v/weylchamber.svg
   :alt: weylchamber on the Python Package Index
   :target: https://pypi.python.org/pypi/weylchamber
.. image:: https://img.shields.io/travis/qucontrol/weylchamber.svg
   :alt: Travis Continuous Integration
   :target: https://travis-ci.org/qucontrol/weylchamber
.. image:: https://ci.appveyor.com/api/projects/status/a407jfh3gl74o1m4?svg=true
   :alt: AppVeyor Continuous Integration
   :target: https://ci.appveyor.com/project/goerz/weylchamber
.. image:: https://img.shields.io/coveralls/github/qucontrol/weylchamber.svg
   :alt: Coveralls
   :target: https://coveralls.io/github/qucontrol/weylchamber?branch=master
.. image:: https://readthedocs.org/projects/weylchamber/badge/?version=latest
   :alt: Documentation Status
   :target: https://weylchamber.readthedocs.io/en/latest/?badge=latest
.. image:: https://img.shields.io/badge/License-BSD-green.svg
   :alt: BSD License
   :target: https://opensource.org/licenses/BSD-3-Clause

Python package for analyzing two-qubit gates in the Weyl chamber

Development of the ``weylchamber`` package happens on `Github`_.
You can read the full documentation at `ReadTheDocs`_.


.. _ReadTheDocs: https://weylchamber.readthedocs.io/en/latest/


Installation
------------

To install the latest released version of the ``weylchamber`` package, run this command in your terminal:

.. code-block:: console

    $ pip install weylchamber

This is the preferred method to install ``weylchamber``, as it will always install the most recent stable release.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


To install the latest development version of ``weylchamber`` from `Github`_.

.. code-block:: console

    $ pip install git+https://github.com/qucontrol/weylchamber.git@master#egg=weylchamber



.. _Github: https://github.com/qucontrol/weylchamber

Usage
-----

To use ``weylchamber`` in a project::

    import weylchamber

See the Tutorial_ for details.

.. _Tutorial: https://weylchamber.readthedocs.io/en/latest/tutorial.html
